import React, { useMemo, useCallback } from "react";
import { useScores } from "~/features/clientLibrary/useScores";
export function useScoreSelection({ scoresMenu, lat, lng, }) {
    const [activeScore, setActiveScore] = React.useState(null);
    const [activeCategory, setActiveCategory] = React.useState(null);
    const { data, isFetching: isScoresFetching } = useScores({
        location: {
            lat,
            lng,
        },
    });
    const scoresData = useMemo(() => {
        if (typeof (data === null || data === void 0 ? void 0 : data.location) === "undefined" || !scoresMenu)
            return {};
        const scores = {};
        Object.keys(data.location).forEach((key) => {
            var _a;
            const singleScoreData = (_a = data === null || data === void 0 ? void 0 : data.location) === null || _a === void 0 ? void 0 : _a[key];
            const category = scoresMenu.categories.find(([_key, categoryData]) => categoryData.scores.some(([scoreKey]) => scoreKey === key));
            scores[key] = {
                text: singleScoreData === null || singleScoreData === void 0 ? void 0 : singleScoreData.text,
                value: Math.round(parseFloat((singleScoreData === null || singleScoreData === void 0 ? void 0 : singleScoreData.value) || "0") * 10) / 10,
                categoryKey: category ? category[0] : null,
                categoryOptions: category ? category[1] : null,
            };
        });
        return scores;
    }, [data, scoresMenu]);
    const activeCategoryData = useMemo(() => {
        if (!activeCategory || !scoresMenu)
            return null;
        const category = scoresMenu.categories.find(([key]) => key === activeCategory);
        if (!category)
            return null;
        return category[1];
    }, [activeCategory, scoresMenu]);
    const handleSelectScore = useCallback((scoreKey) => () => {
        setActiveScore((prev) => (prev === scoreKey ? null : scoreKey));
    }, [setActiveScore]);
    const handleSelectCategory = useCallback((categoryKey) => () => {
        setActiveCategory((prev) => (prev === categoryKey ? null : categoryKey));
    }, [setActiveCategory]);
    return {
        isLoading: isScoresFetching,
        scoresData,
        activeScore,
        activeScoreData: activeScore === null ? undefined : scoresData[activeScore],
        activeCategory,
        activeCategoryData,
        handleSelectScore,
        handleSelectCategory,
    };
}
//# sourceMappingURL=useScoreSelection.js.map