export function addAffordabilityComparisonToNeighborhood(baseNeighborhood, comparingNeighborhood) {
    if (!baseNeighborhood.affordability || !comparingNeighborhood.affordability) {
        return comparingNeighborhood;
    }
    // The above check should be enough. However the API cannot always be trusted and sometimes it returns
    // empty objects. This should be fixed eventually, but better safe than sorry
    if (Object.keys(baseNeighborhood.affordability).length === 0 ||
        Object.keys(comparingNeighborhood.affordability).length === 0) {
        return comparingNeighborhood;
    }
    let comparedValues = 0;
    let comparableIndex = 0;
    Object.entries(baseNeighborhood.affordability).forEach(([key, value]) => {
        const affordabilityValue = comparingNeighborhood.affordability[key];
        if (typeof affordabilityValue !== "undefined") {
            comparedValues += 1;
            const priceDifference = Math.abs(value.median_price.value - affordabilityValue.median_price.value);
            const percentageDifference = Math.floor((priceDifference / value.median_price.value) * 100);
            if (percentageDifference >= 15) {
                if (affordabilityValue.median_price.value > value.median_price.value) {
                    comparableIndex += 1;
                }
                else if (affordabilityValue.median_price.value < value.median_price.value) {
                    comparableIndex -= 1;
                }
            }
        }
    });
    let affordabilityComparison = "comparable";
    if (comparableIndex > 0) {
        affordabilityComparison = "moreExpensive";
    }
    else if (comparableIndex < 0) {
        affordabilityComparison = "lessExpensive";
    }
    return Object.assign(Object.assign({}, comparingNeighborhood), { affordabilityComparison: comparedValues > 0 ? affordabilityComparison : undefined });
}
//# sourceMappingURL=affordability.js.map